@@ -38,6 +38,7 @@ class SessionMode(common_mix.EnumAutoName):
     VIEW_MODE = 1
     INTERNAL_MODE = 2
     RESTORE_REPOS_MODE = 3
+    CUSTOM_EXECUTION_MODE = 4
 #~ class SessionMode
 
 class ConfigClasses(common_mix.EnumAutoName):
@@ -104,6 +105,9 @@ class CompleteConfiguration(object):
     # keepoutput summary for the following criteria (may run slower)
     CRITERIA_WITH_OUTPUT_SUMMARY = []
 
+    # Decides whether to hash the output log
+    HASH_OUTLOG = True
+
     # PARALELISM
     SINGLE_REPO_PARALLELISM = 1 # Max number of parallel exec in a repo dir
 
@@ -238,6 +242,8 @@ class CompleteConfiguration(object):
 
     ]
 
+    TESTCASES_SELECTION = None
+
     # Reporting
     REPORT_NUMBER_OF_TESTS_GENERATED = True
     REPORT_NUMBER_OF_DUPLICATED_TESTS = True
@@ -289,7 +295,7 @@ class CompleteConfiguration(object):
 
     CRITERIA_RESTRICTION_ENABLED = True  # Enable restricting mutation(scope)
 
-    # criterion: selection tools. Example: SM and TCE of E-SELECTIVE
+    # criterion: selection tools. Example: SM and TCE or E-SELECTIVE
     CRITERIA_ELEM_SELECTIONS = {
         
     }
