@@ -113,7 +113,11 @@ class BaseTestcaseTool(abc.ABC):
         if self.compress_test_storage_dir:
             if os.path.isfile(self.tests_storage_dir_archive):
                 if os.path.isdir(self.tests_storage_dir):
-                    shutil.rmtree(self.tests_storage_dir)
+                    try:
+                        shutil.rmtree(self.tests_storage_dir)
+                    except PermissionError:
+                        self._dir_chmod777(self.tests_storage_dir)
+                        shutil.rmtree(self.tests_storage_dir)
                 common_fs.TarGz.decompressDir(self.tests_storage_dir_archive)
     #~ def __init__()
 
@@ -122,7 +126,11 @@ class BaseTestcaseTool(abc.ABC):
         if self.compress_test_storage_dir:
             if os.path.isfile(self.tests_storage_dir_archive) \
                                     and os.path.isdir(self.tests_storage_dir):
-                shutil.rmtree(self.tests_storage_dir)
+                try:
+                    shutil.rmtree(self.tests_storage_dir)
+                except PermissionError:
+                    self._dir_chmod777(self.tests_storage_dir)
+                    shutil.rmtree(self.tests_storage_dir)
     #~ def __del__()
 
     def clear_working_dir(self):
@@ -381,7 +389,8 @@ class BaseTestcaseTool(abc.ABC):
         ptest_tresh = 5
 
         def test_exec_iteration(testcase):
-            processbar.set_description("Running Test %s"% testcase)
+            processbar.set_description("Running Test {} (x{})".format(\
+                                                  testcase, parallel_count))
             start_time = time.time()
             test_failed, execoutlog_hash = \
                         self._oracle_execute_a_test(testcase, exe_path_map, \
@@ -402,16 +411,13 @@ class BaseTestcaseTool(abc.ABC):
         #~ def test_exec_iteration()
 
         if self.can_run_tests_in_parallel() and len(testcases) >= ptest_tresh \
-                            and (parallel_count is None or parallel_count > 1):
-            if parallel_count is None:
-                paralle_count = min(len(testcases), \
-                                                multiprocessing.cpu_count())
-            else:
-                paralle_count = min(len(testcases), parallel_count)
-            joblib.Parallel(n_jobs=paralle_count, require='sharedmem')\
+                        and parallel_count is not None and parallel_count > 1:
+            parallel_count = min(len(testcases), parallel_count)
+            joblib.Parallel(n_jobs=parallel_count, require='sharedmem')\
                             (joblib.delayed(test_exec_iteration)(testcase) \
                                                 for testcase in processbar)
         else:
+            parallel_count = 1 # to be printed in progress
             for testcase in processbar: 
                 test_failed = test_exec_iteration(testcase)
                 if stop_on_failure and test_failed != \
@@ -639,4 +645,4 @@ class BaseTestcaseTool(abc.ABC):
                                         max_time=None):
         print ("!!! Must be implemented in child class !!!")
     #~ def _do_generate_tests()
-#~ class BaseTestcaseTool
\ No newline at end of file
+#~ class BaseTestcaseTool
