@@ -3,6 +3,7 @@ from __future__ import print_function
 import os
 import sys
 import re
+import shutil
 import imp
 from distutils.spawn import find_executable
 
@@ -67,6 +68,21 @@ class KTestTestFormat(object):
         prog, args = cls._get_replay_prog_args(executable_file, test_file, \
                                                 custom_replay_tool_binary_dir)
 
+        # klee-replay may create files or dir. in KLEE version with LLVM-3.4,
+        # those are created in a temporary dir set as <cwd>.temps
+        # XXX XXX. make sure each test has its own
+        test_work_dir = test_file+".execdir"
+        klee_replay_temps = test_work_dir + '.temps'
+        if not os.path.isdir(test_work_dir):
+            os.mkdir(test_work_dir)
+        if os.path.isdir(klee_replay_temps):
+            try:
+                shutil.rmtree(klee_replay_temps)
+            except PermissionError:
+                cls._dir_chmod777(klee_replay_temps)
+                shutil.rmtree(klee_replay_temps)
+
+        # XXX Execution setup
         tmp_env = os.environ.copy()
         if env_vars is not None:
             #for e, v in env_vars.items():
@@ -80,11 +96,16 @@ class KTestTestFormat(object):
             tmp_env['KLEE_REPLAY_TIMEOUT'] = str(timeout)
             kt_over = 5 # 1second
             timeout += kt_over
+        else:
+            # DBG
+            logging.warning("@KTEST: calling ktest execution without timeout.")
+        
+        # XXX Execute the ktest
         if collected_output is not None:
             retcode, out, err = DriversUtils.execute_and_get_retcode_out_err(\
                                 prog=prog, args_list=args, env=tmp_env, \
                                 timeout=timeout, timeout_grace_period=5, \
-                                                        merge_err_to_out=True)
+                                merge_err_to_out=True, cwd=test_work_dir)
             out = cls._remove_output_noise(out)
             collected_output.extend((retcode, out, \
                                             (retcode in timeout_return_codes)))
@@ -92,7 +113,16 @@ class KTestTestFormat(object):
             retcode, out, err = DriversUtils.execute_and_get_retcode_out_err(\
                                 prog=prog, args_list=args, env=tmp_env, \
                                 timeout=timeout, timeout_grace_period=5, \
-                                                    out_on=False, err_on=False)
+                                                out_on=False, err_on=False, \
+                                                cwd=test_work_dir)
+
+        # XXX: Go back to previous CWD
+        if os.path.isdir(klee_replay_temps):
+            try:
+                shutil.rmtree(klee_replay_temps)
+            except PermissionError:
+                cls._dir_chmod777(klee_replay_temps)
+                shutil.rmtree(klee_replay_temps)
 
         if retcode in timeout_return_codes + \
                                     DriversUtils.EXEC_SEGFAULT_OUT_RET_CODE:
@@ -103,6 +133,22 @@ class KTestTestFormat(object):
         return verdict
     #~ def execute_test()
 
+    @staticmethod
+    def _dir_chmod777(dirpath):
+        try:
+            for root_, dirs_, files_ in os.walk(dirpath):
+                for sub_d in dirs_:
+                    os.chmod(os.path.join(root_, sub_d), 0o777)
+                for f_ in files_:
+                    os.chmod(os.path.join(root_, f_), 0o777)
+        except PermissionError:
+            ret,out,_ = DriversUtils.execute_and_get_retcode_out_err('sudo', \
+                                            ['chmod', '777', '-R', dirpath])
+            ERROR_HANDLER.assert_true(ret == 0, \
+                        "'sudo chmod 777 -R "+dirpath+"' failed (returned "+\
+                                        str(ret)+"), error: "+out, __file__)
+    #~ def _dir_chmod777()
+    
     @classmethod
     def get_replay_test_wrapper_str(cls, exe_env_var, ktest_env_var, \
                                                             timeout_env_var, \
